# SPDX-License-Identifier: CC0-1.0

"""
Haketilo unit tests - default script blocking policy dialog
"""

# This file is part of Haketilo
#
# Copyright (C) 2022, Wojtek Kosior <koszko@koszko.org>
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the CC0 1.0 Universal License as published by
# the Creative Commons Corporation.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# CC0 1.0 Universal License for more details.

import pytest

from ..extension_crafting import ExtraHTML
from ..script_loader import load_script
from .utils import broker_js

@pytest.mark.ext_data({
    'background_script': broker_js,
    'extra_html': ExtraHTML(
        'html/default_blocking_policy.html',
        {
            'html/default_blocking_policy.js':
            'init_default_policy_dialog();'
        }
    ),
    'navigate_to': 'html/default_blocking_policy.html'
})
@pytest.mark.usefixtures('webextension')
def test_default_blocking_policy_dialog(driver, wait_elem_text):
    """
    A test case for the dialog that facilitates toggling the default policy of
    script blocking.
    """
    wait_elem_text('current_policy_span', 'block')

    driver.find_element_by_id('toggle_policy_but').click()
    wait_elem_text('current_policy_span', 'allow')

    driver.find_element_by_id('toggle_policy_but').click()
    wait_elem_text('current_policy_span', 'block')
